@@ -1,9 +1,12 @@
-from .fj2 import FJ2FactoryManager
-from .rapt_fm import RaptFactoryManager
-from .iffm import InsuranceFraudFactoryManager
-from .saha import SAHAFactoryManager
+# -*- coding: utf-8 -*-
 from .cheap_buyer.cheapbuyer import CheapBuyerFactoryManager
+from .fj2 import FJ2FactoryManager
+from .iffm import InsuranceFraudFactoryManager
+from .monopoly import Monopoly
 from .nvm.nmv_agent import NVMFactoryManager
+from .psfm import PenaltySabotageFactoryManager
+from .rapt_fm import RaptFactoryManager
+from .saha import SAHAFactoryManager
 
 __all__ = [
     "FJ2FactoryManager",
@@ -12,4 +15,6 @@ __all__ = [
     "SAHAFactoryManager",
     "CheapBuyerFactoryManager",
     "NVMFactoryManager",
+    "Monopoly",
+    "PenaltySabotageFactoryManager",
 ]
