@@ -11,31 +11,39 @@ Agent Information
   - Country: Japan
   - Team Members:
     1. Ayan Sengupta <a-sengupta@nec.com>
-       
+
 """
-from collections import namedtuple
 import copy
-from abc import ABC
 import itertools
+from abc import ABC
+from collections import defaultdict, namedtuple
+from typing import Any, Dict, List, Optional, Tuple, Union
+
+import matplotlib.pyplot as plt
+import numpy as np
+from negmas import (
+    AgentMechanismInterface,
+    AspirationNegotiator,
+    Contract,
+    Issue,
+    LinearUtilityFunction,
+    Negotiator,
+    ResponseType,
+    SAONegotiator,
+    ToughNegotiator,
+)
+from negmas.common import PreferencesChange, PreferencesChangeType
+from negmas.helpers import get_class, instantiate
+from negmas.outcomes.base_issue import make_issue
 from scml.scml2020 import (
-    SCML2020Agent,
-    SCML2020World,
-    RandomAgent,
     DecentralizingAgent,
     DoNothingAgent,
     NegotiationManager,
+    RandomAgent,
+    SCML2020Agent,
+    SCML2020World,
     Simulation,
 )
-import matplotlib.pyplot as plt
-from scml.scml2020.components import (
-    SupplyDrivenProductionStrategy,
-    NegotiationManager,
-    IndependentNegotiationsManager,
-    PredictionBasedTradingStrategy,
-    ReactiveTradingStrategy,
-    TradingStrategy,
-    SignAll,
-)
 
 # required for development
 from scml.scml2020.agents import (
@@ -43,22 +51,15 @@ from scml.scml2020.agents import (
     DecentralizingAgent,
     DoNothingAgent,
 )
-from negmas.outcomes import ResponseType
-from negmas.helpers import get_class, instantiate
-from typing import Tuple, List, Union, Any, Optional, Dict
-from negmas import (
-    Contract,
-    Issue,
-    AgentMechanismInterface,
-    Negotiator,
-    SAONegotiator,
-    AspirationNegotiator,
-    ToughNegotiator,
+from scml.scml2020.components import (
+    IndependentNegotiationsManager,
+    NegotiationManager,
+    PredictionBasedTradingStrategy,
+    ReactiveTradingStrategy,
+    SignAll,
+    SupplyDrivenProductionStrategy,
+    TradingStrategy,
 )
-import numpy as np
-from negmas import LinearUtilityFunction
-from collections import defaultdict
-
 
 __all__ = ["Merchant"]
 
@@ -95,14 +96,14 @@ class ToughAspirationNegotiator(AspirationNegotiator):
             return ResponseType.ACCEPT_OFFER
 
         if self.ufun_max is None or self.ufun_min is None:
-            self.on_ufun_changed()
-        if self._utility_function is None:
+            self.on_preferences_changed([PreferencesChange(PreferencesChangeType.General)])
+        if self.ufun is None:
             return ResponseType.REJECT_OFFER
-        u = self._utility_function(offer)
+        u = self.ufun(offer)
         if u is None or u < self.reserved_value:
             return ResponseType.REJECT_OFFER
         asp = (
-            self.aspiration(state.relative_time) * (self.ufun_max - self.ufun_min)
+            self.utility_at(state.relative_time) * (self.ufun_max - self.ufun_min)
             + self.ufun_min
         )
         if u >= asp and u > self.reserved_value:
@@ -118,7 +119,7 @@ class ToughAspirationNegotiator(AspirationNegotiator):
             return (2, self.exec_time, 1)
 
         asp = (
-            self.aspiration(state.relative_time) * (self.ufun_max - self.ufun_min)
+            self.utility_at(state.relative_time) * (self.ufun_max - self.ufun_min)
             + self.ufun_min
         )
 
@@ -440,9 +441,9 @@ class GryffindorIndependentNegotiationsManager(IndependentNegotiationsManager):
     ):
 
         issues = [
-            Issue(qvalues, name="quantity"),
-            Issue(tvalues, name="time"),
-            Issue(uvalues, name="uvalues"),
+            make_issue((int(qvalues[0]), int(max(qvalues))), name="quantity"),
+            make_issue((int(tvalues[0]), int(max(tvalues))), name="time"),
+            make_issue((int(uvalues[0]), int(max(uvalues))), name="unit_price"),
         ]
 
         for partner in partners:
@@ -743,5 +744,5 @@ class Merchant(
     def create_ufun(self, is_seller: bool, issues=None, outcomes=None):
         """A utility function that penalizes high cost and late delivery for buying and and awards them for selling"""
         if is_seller:
-            return LinearUtilityFunction((0, 0.1, 1))
-        return LinearUtilityFunction((0, -0.1, -1))
+            return LinearUtilityFunction((0, 0.1, 1), issues=issues, outcomes=outcomes)
+        return LinearUtilityFunction((0, -0.1, -1), issues=issues, outcomes=outcomes)
