@@ -3,71 +3,78 @@
 *Authors* type-your-team-member-names-with-their-emails here
 
 
-This code is free to use or update given that proper attribution is given to 
-the authors and the ANAC 2020 SCML. 
+This code is free to use or update given that proper attribution is given to
+the authors and the ANAC 2020 SCML.
 
-This module implements a factory manager for the SCM 2020 league of ANAC 2019 
-competition. This version will use subcomponents. Please refer to the 
-[game description](http://www.yasserm.com/scml/scml2020.pdf) for all the 
+This module implements a factory manager for the SCM 2020 league of ANAC 2019
+competition. This version will use subcomponents. Please refer to the
+[game description](http://www.yasserm.com/scml/scml2020.pdf) for all the
 callbacks and subcomponents available.
 
-Your agent can learn about the state of the world and itself by accessing 
+Your agent can learn about the state of the world and itself by accessing
 properties in the AWI it has. For example:
 
-- The number of simulation steps (days): self.awi.n_steps  
+- The number of simulation steps (days): self.awi.n_steps
 - The current step (day): self.awi.current_steps
 - The factory state: self.awi.state
 - Availability for producton: self.awi.available_for_production
 
 
-Your agent can act in the world by calling methods in the AWI it has. 
+Your agent can act in the world by calling methods in the AWI it has.
 For example:
 
 - *self.awi.request_negotiation(...)*  # requests a negotiation with one partner
 - *self.awi.request_negotiations(...)* # requests a set of negotiations
 
- 
+
 You can access the full list of these capabilities on the documentation.
 
-- For properties/methods available only to SCM agents, check the list 
+- For properties/methods available only to SCM agents, check the list
   [here](http://www.yasserm.com/scml/scml2020docs/api/scml.scml2020.AWI.html)
 
 """
 
-# required for development
-from scml.scml2020.agents import DoNothingAgent
-
 # required for running the test tournament
 import time
-from tabulate import tabulate
-from scml.scml2020.utils import anac2020_std, anac2020_collusion
-from scml.scml2020.agents import DecentralizingAgent, BuyCheapSellExpensiveAgent
-from negmas.helpers import humanize_time
 
 # required for typing
-from typing import List, Optional, Dict, Any
+from typing import Any, Dict, List, Optional, Tuple
+
 import numpy as np
 from negmas import (
-    Issue,
     AgentMechanismInterface,
-    Contract,
-    Negotiator,
-    MechanismState,
     Breach,
+    Contract,
+    Issue,
+    MechanismState,
+    Negotiator,
+    ResponseType,
+    SAOSyncController,
+    outcome_is_valid,
 )
-from scml.scml2020.world import Failure
-from scml.scml2020 import SCML2020Agent
-from scml.scml2020 import PredictionBasedTradingStrategy
-from scml.scml2020 import MovingRangeNegotiationManager, StepNegotiationManager
-from scml.scml2020 import DemandDrivenProductionStrategy, SupplyDrivenProductionStrategy
-
-
-from scml.scml2020 import TIME, QUANTITY, UNIT_PRICE
-from negmas import ResponseType, outcome_is_valid
+from negmas.helpers import humanize_time
 from negmas.sao import SAOResponse
-from typing import List, Dict, Optional, Tuple, Any
-from negmas import SAOSyncController
-import numpy as np
+from scml.scml2020 import (
+    QUANTITY,
+    TIME,
+    UNIT_PRICE,
+    DemandDrivenProductionStrategy,
+    Failure,
+    MovingRangeNegotiationManager,
+    PredictionBasedTradingStrategy,
+    SCML2020Agent,
+    StepNegotiationManager,
+    SupplyDrivenProductionStrategy,
+)
+
+# required for development
+from scml.scml2020.agents import (
+    BuyCheapSellExpensiveAgent,
+    DecentralizingAgent,
+    DoNothingAgent,
+)
+from scml.scml2020.utils import anac2020_collusion, anac2020_std
+from tabulate import tabulate
 
 __all__ = ["BARGentCovid19"]
 
@@ -149,7 +156,7 @@ class SyncController(SAOSyncController):
 
     def is_valid(self, negotiator_id: str, offer: "Outcome") -> bool:
         """Is this a valid offer for that negotiation"""
-        issues = self.negotiators[negotiator_id][0].ami.issues
+        issues = self.negotiators[negotiator_id][0].nmi.issues
         return outcome_is_valid(offer, issues)
 
     def counter_all(
@@ -241,14 +248,14 @@ class SyncController(SAOSyncController):
             The outcome with highest utility and the corresponding utility
         """
         negotiator = self.negotiators[nid][0]
-        if negotiator.ami is None:
+        if negotiator.nmi is None:
             return None, -1000
-        utils = np.array([self.utility(_) for _ in negotiator.ami.outcomes])
+        utils = np.array([self.utility(_) for _ in negotiator.nmi.outcomes])
         best_indx = np.argmax(utils)
         self._best_utils[nid] = utils[best_indx]
         if utils[best_indx] < 0:
             return None, utils[best_indx]
-        return negotiator.ami.outcomes[best_indx], utils[best_indx]
+        return negotiator.nmi.outcomes[best_indx], utils[best_indx]
 
 
 class MyNegotiationManager:
@@ -385,10 +392,10 @@ class MyNegotiationManager:
         return controller
 
 
+from typing import Dict, List, Tuple
+
 import numpy as np
 from negmas import Contract
-from typing import List, Dict, Tuple
-
 from scml.scml2020.common import NO_COMMAND
 
 
@@ -672,18 +679,15 @@ class _NegotiationCallbacks:
         return needed[steps[0] : steps[1]] - secured[steps[0] : steps[1]]
 
 
-import numpy as np
 from pprint import pformat
 from typing import List, Optional
 
+import numpy as np
 from negmas import Contract
-
-from scml.scml2020.components import FixedTradePredictionStrategy, SignAllPossible
-from scml.scml2020.common import is_system_agent
-from scml.scml2020.common import ANY_LINE
-from scml.scml2020.components.prediction import MeanERPStrategy
-
 from scml.scml2020 import TradingStrategy
+from scml.scml2020.common import ANY_LINE, is_system_agent
+from scml.scml2020.components import FixedTradePredictionStrategy, SignAllPossible
+from scml.scml2020.components.prediction import MeanERPStrategy
 
 
 class MyPredictionBasedTradingStrategy(
@@ -759,7 +763,7 @@ class MyPredictionBasedTradingStrategy(
     def sign_all_contracts(self, contracts: List[Contract]) -> List[Optional[str]]:
         # sort contracts by time and then put system contracts first within each time-step
         signatures = [None] * len(contracts)
-        max_price = max([x.agreement["unit_price"] for x in contracts])
+        max_price = max(x.agreement["unit_price"] for x in contracts)
         contracts = sorted(
             zip(contracts, range(len(contracts))),
             key=lambda x: (
@@ -849,9 +853,9 @@ class BARGentCovid19(
     """
     This is the only class you *need* to implement. You can create the agent
     by combining the following strategies:
-    
+
     1. A trading strategy that decides the quantities to sell and buy
-    2. A negotiation manager that decides which negotiations to engage in and 
+    2. A negotiation manager that decides which negotiations to engage in and
        uses some controller(s) to control the behavior of all negotiators
     3. A production strategy that decides what to produce
     """
