@@ -35,21 +35,41 @@ You can access the full list of these capabilities on the documentation.
 
 """
 
+import csv
+import functools
+import math
+import random
+
 # required for running the test tournament
 import time
-import numpy as np
-import math
-import functools
-import random
-import csv
-from collections import defaultdict
-from typing import Any, Dict, List, Optional, Iterable, Union, Tuple, Callable, Type
 from abc import abstractmethod
-from dataclasses import dataclass, asdict
+from collections import defaultdict
+from dataclasses import asdict, dataclass
 from pprint import pformat
-from tabulate import tabulate
+from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Type, Union
 
-from scml.scml2020 import SCML2020Agent
+import numpy as np
+from negmas import (
+    AgentMechanismInterface,
+    AgentWorldInterface,
+    AspirationNegotiator,
+    Breach,
+    Contract,
+    ControlledNegotiator,
+    Issue,
+    LinearUtilityFunction,
+    MechanismState,
+    Negotiator,
+    PolyAspiration,
+    ResponseType,
+    SAONegotiator,
+    UtilityFunction,
+    num_outcomes,
+)
+from negmas.events import Notification, Notifier
+from negmas.helpers import get_class, humanize_time, instantiate
+from negmas.sao import SAOController
+from scml.scml2020 import Failure, SCML2020Agent
 from scml.scml2020.agents import (
     BuyCheapSellExpensiveAgent,
     DecentralizingAgent,
@@ -58,40 +78,20 @@ from scml.scml2020.agents import (
     MovingRangeAgent,
     ReactiveAgent,
 )
-from scml.scml2020.utils import anac2020_collusion, anac2020_std
-from scml.scml2020.world import Failure
-from scml.scml2020.common import is_system_agent, ANY_LINE, NO_COMMAND, TIME, QUANTITY
-from scml.scml2020.components.production import ProductionStrategy
+from scml.scml2020.common import ANY_LINE, NO_COMMAND, QUANTITY, TIME, is_system_agent
 from scml.scml2020.components.negotiation import (
     NegotiationManager,
     StepNegotiationManager,
 )
-from scml.scml2020.components.trading import TradingStrategy
 from scml.scml2020.components.prediction import (
     ExecutionRatePredictionStrategy,
     MeanERPStrategy,
 )
+from scml.scml2020.components.production import ProductionStrategy
+from scml.scml2020.components.trading import TradingStrategy
 from scml.scml2020.services.controllers import StepController, SyncController
-
-from negmas import LinearUtilityFunction
-from negmas import (
-    AspirationMixin,
-    AgentWorldInterface,
-    PassThroughNegotiator,
-    ResponseType,
-    SAONegotiator,
-    AspirationNegotiator,
-    AgentMechanismInterface,
-    Breach,
-    Contract,
-    Issue,
-    MechanismState,
-    Negotiator,
-    UtilityFunction,
-)
-from negmas.sao import SAOController
-from negmas.events import Notifier, Notification
-from negmas.helpers import humanize_time, get_class, instantiate
+from scml.scml2020.utils import anac2020_collusion, anac2020_std
+from tabulate import tabulate
 
 __all__ = ["MercuAgent"]
 
@@ -124,7 +124,15 @@ class MyNegotiator(SAONegotiator):
         if self._Negotiator__parent:
             return self._Negotiator__parent.on_negotiation_end(self.id, state)
 
-    def join(self, ami, state, *, ufun=None, role="agent",) -> bool:
+    def join(
+        self,
+        nmi,
+        state,
+        *,
+        preferences: Optional["UtilityFunction"] = None,
+        ufun=None,
+        role="agent",
+    ) -> bool:
         """
         Joins a negotiation.
 
@@ -136,21 +144,21 @@ class MyNegotiator(SAONegotiator):
         permission = (
             self._Negotiator__parent is None
             or self._Negotiator__parent.before_join(
-                self.id, ami, state, ufun=ufun, role=role
+                self.id, nmi, state, ufun=ufun, role=role
             )
         )
         if not permission:
             return False
-        if super().join(ami, state, ufun=ufun, role=role):
+        if super().join(nmi, state, ufun=ufun, preferences=preferences, role=role):
             if self._Negotiator__parent:
                 self._Negotiator__parent.after_join(
-                    self.id, ami, state, ufun=ufun, role=role
+                    self.id, nmi, state, ufun=ufun, role=role
                 )
             return True
         return False
 
 
-class MyController(SAOController, AspirationMixin, Notifier):
+class MyController(SAOController, Notifier):
     def __init__(
         self,
         *args,
@@ -180,6 +188,7 @@ class MyController(SAOController, AspirationMixin, Notifier):
         self.urange = urange
         self.partners = partners
         self.product = product
+        self.__asp = PolyAspiration(max_aspiration=1.0, aspiration_type="boulware")
         negotiator_params = (
             negotiator_params if negotiator_params is not None else dict()
         )
@@ -199,19 +208,22 @@ class MyController(SAOController, AspirationMixin, Notifier):
     def join(
         self,
         negotiator_id: str,
-        ami: AgentMechanismInterface,
+        nmi: AgentMechanismInterface,
         state: MechanismState,
         *,
+        preferences: Optional["UtilityFunction"] = None,
         ufun: Optional["UtilityFunction"] = None,
         role: str = "agent",
     ) -> bool:
-        joined = super().join(negotiator_id, ami, state, ufun=ufun, role=role)
+        joined = super().join(
+            negotiator_id, nmi, state, preferences=preferences, ufun=ufun, role=role
+        )
         if joined:
             self.completed[negotiator_id] = False
         return joined
 
     def propose(self, negotiator_id: str, state: MechanismState) -> Optional["Outcome"]:
-        self.__negotiator._ami = self.negotiators[negotiator_id][0]._ami
+        self.__negotiator._nmi = self.negotiators[negotiator_id][0]._nmi
         return self.__negotiator.propose(state)
 
     def respond(
@@ -220,7 +232,7 @@ class MyController(SAOController, AspirationMixin, Notifier):
         # 必要数量達成済み
         if self.secured >= self.target:
             return ResponseType.END_NEGOTIATION
-        self.__negotiator._ami = self.negotiators[negotiator_id][0]._ami
+        self.__negotiator._nmi = self.negotiators[negotiator_id][0]._nmi
         return self.__negotiator.respond(offer=offer, state=state)
 
     def __str__(self):
@@ -230,13 +242,22 @@ class MyController(SAOController, AspirationMixin, Notifier):
             f"({len([_ for _ in self.completed.values() if _])} completed of {len(self.completed)} negotiators)"
         )
 
+    def _create_ufun(self, is_seller: bool, issues=None, outcomes=None):
+        """A utility function that penalizes high cost and late delivery for buying and and awards them for selling"""
+        if is_seller:
+            return LinearUtilityFunction((0, 0.25, 1))
+        return LinearUtilityFunction((0, -0.5, -0.8))
+
     def create_negotiator(
         self,
         negotiator_type: Union[str, Type[MyNegotiator]] = None,
         name: str = None,
         cntxt: Any = None,
+        seller: bool = True,
         **kwargs,
     ) -> MyNegotiator:
+        ufun = self._create_ufun(seller)
+        kwargs["ufun"] = ufun
         neg = super().create_negotiator(negotiator_type, name, cntxt, **kwargs)
         self.completed[neg.id] = False
         return neg
@@ -288,7 +309,7 @@ class MyController(SAOController, AspirationMixin, Notifier):
                 else:
                     return
                 self.retries[partner] += 1
-                neg = self.create_negotiator()
+                neg = self.create_negotiator(seller=not self.is_seller)
                 self.completed[neg.id] = False
                 self.awi.loginfo(
                     f"{str(self)} negotiating with {partner} on u={self.urange}"
@@ -431,7 +452,7 @@ class MyNegotiationManager(NegotiationManager):
             return None
         self.awi.loginfo_agent(
             f"Accepting request from {initiator}: {[str(_) for _ in mechanism.issues]} "
-            f"({Issue.num_outcomes(mechanism.issues)})"
+            f"({num_outcomes(mechanism.issues)})"
         )
         # create a controller for the time-step if one does not exist or use the one already running
         if controller_info.controller is None:
@@ -446,7 +467,7 @@ class MyNegotiationManager(NegotiationManager):
             controller = controller_info.controller
 
         # create a new negotiator, add it to the controller and return it
-        return controller.create_negotiator()
+        return controller.create_negotiator(seller=is_seller)
 
     def all_negotiations_concluded(
         self, controller_index: int, is_seller: bool
@@ -1038,10 +1059,10 @@ def run(
     **Not needed for submission.** You can use this function to test your agent.
 
     Args:
-        competition: The competition type to run (possibilities are std, 
-                     collusion).        
+        competition: The competition type to run (possibilities are std,
+                     collusion).
         n_steps:     The number of simulation steps.
-        n_configs:   Number of different world configurations to try. 
+        n_configs:   Number of different world configurations to try.
                      Different world configurations will correspond to
                      different number of factories, profiles
                      , production graphs etc
@@ -1053,7 +1074,7 @@ def run(
     Remarks:
 
         - This function will take several minutes to run.
-        - To speed it up, use a smaller `n_step` value        
+        - To speed it up, use a smaller `n_step` value
 
     """
     competitors = [MercuAgent, DecentralizingAgent, BuyCheapSellExpensiveAgent]
