@@ -3,69 +3,69 @@
 *Authors* type-your-team-member-names-with-their-emails here
 
 
-This code is free to use or update given that proper attribution is given to 
-the authors and the ANAC 2020 SCML. 
+This code is free to use or update given that proper attribution is given to
+the authors and the ANAC 2020 SCML.
 
-This module implements a factory manager for the SCM 2020 league of ANAC 2019 
-competition. This version will not use subcomponents. Please refer to the 
-[game description](http://www.yasserm.com/scml/scml2020.pdf) for all the 
+This module implements a factory manager for the SCM 2020 league of ANAC 2019
+competition. This version will not use subcomponents. Please refer to the
+[game description](http://www.yasserm.com/scml/scml2020.pdf) for all the
 callbacks and subcomponents available.
 
-Your agent can learn about the state of the world and itself by accessing 
+Your agent can learn about the state of the world and itself by accessing
 properties in the AWI it has. For example:
 
-- The number of simulation steps (days): self.awi.n_steps  
+- The number of simulation steps (days): self.awi.n_steps
 - The current step (day): self.awi.current_steps
 - The factory state: self.awi.state
 - Availability for producton: self.awi.available_for_production
 
 
-Your agent can act in the world by calling methods in the AWI it has. 
+Your agent can act in the world by calling methods in the AWI it has.
 For example:
 
 - *self.awi.request_negotiation(...)*  # requests a negotiation with one partner
 - *self.awi.request_negotiations(...)* # requests a set of negotiations
 
- 
+
 You can access the full list of these capabilities on the documentation.
 
-- For properties/methods available only to SCM agents, check the list 
+- For properties/methods available only to SCM agents, check the list
   [here](https://scml.readthedocs.io/en/latest/api/scml.scml2020.AWI.html)
 
 """
 
-# required for running the test tournament
-import time
-
-# required for typing
-from typing import Any, Dict, List, Optional, Type, Tuple
-
-import numpy as np
 import copy
-from itertools import chain, combinations
-from random import randint, sample
 import math
 
+# required for running the test tournament
+import time
+from itertools import chain, combinations
+from random import randint, sample
+
+# required for typing
+from typing import Any, Dict, List, Optional, Tuple, Type
+
+import numpy as np
 from negmas import (
     AgentMechanismInterface,
+    AspirationNegotiator,
     Breach,
     Contract,
     Issue,
     MechanismState,
     Negotiator,
-    UtilityFunction,
-    SAONegotiator,
-    AspirationNegotiator,
-    UtilityValue,
     Outcome,
+    SAONegotiator,
+    UtilityFunction,
+    Value,
 )
 from negmas.helpers import humanize_time
-from scml.scml2020 import SCML2020Agent
+from negmas.outcomes.issue_ops import enumerate_issues
+from scml.scml2020 import AWI, Failure, SCML2020Agent
 
 # required for development
 from scml.scml2020.agents import BuyCheapSellExpensiveAgent, DecentralizingAgent
 from scml.scml2020.utils import anac2020_collusion, anac2020_std
-from scml.scml2020.world import Failure, AWI
 from tabulate import tabulate
 
 __all__ = ["GreedyFactoryManager2"]
@@ -73,10 +73,10 @@ __all__ = ["GreedyFactoryManager2"]
 
 class GFM2(SCML2020Agent):
     """
-    This is the only class you *need* to implement. The current skeleton has a 
+    This is the only class you *need* to implement. The current skeleton has a
     basic do-nothing implementation.
-    You can modify any parts of it as you need. You can act in the world by 
-    calling methods in the agent-world-interface instantiated as `self.awi` 
+    You can modify any parts of it as you need. You can act in the world by
+    calling methods in the agent-world-interface instantiated as `self.awi`
     in your agent. See the documentation for more details
 
     """
@@ -162,11 +162,6 @@ class GFM2(SCML2020Agent):
             )
             uvalues = (1, self.awi.catalog_prices[self.awi.my_input_product])
             print_log(f"tvalues={tvalues}")
-            issues = [
-                Issue(qvalues, name="quantity"),
-                Issue(tvalues, name="time"),
-                Issue(uvalues, name="uvalues"),
-            ]
             for _ in range(5):
                 for partner in self.awi.my_suppliers:
                     self.awi.request_negotiation(
@@ -176,7 +171,7 @@ class GFM2(SCML2020Agent):
                         unit_price=uvalues,
                         time=tvalues,
                         partner=partner,
-                        negotiator=self.negotiator(False, issues=issues),
+                        negotiator=self.negotiator(False),
                     )
 
         # output products
@@ -191,11 +186,6 @@ class GFM2(SCML2020Agent):
                 ),
                 self.awi.catalog_prices[self.awi.my_output_product] * 4,
             )
-            issues = [
-                Issue(qvalues, name="quantity"),
-                Issue(tvalues, name="time"),
-                Issue(uvalues, name="uvalues"),
-            ]
             for _ in range(5):
                 for partner in self.awi.my_consumers:
                     self.awi.request_negotiation(
@@ -205,7 +195,7 @@ class GFM2(SCML2020Agent):
                         unit_price=uvalues,
                         time=tvalues,
                         partner=partner,
-                        negotiator=self.negotiator(True, issues=issues),
+                        negotiator=self.negotiator(True),
                     )
 
     # ================================
@@ -236,12 +226,8 @@ class GFM2(SCML2020Agent):
     def negotiator(self, is_seller: bool, issues=None) -> Optional[SAONegotiator]:
         """Creates a negotiator"""
 
-        if issues is None or not Issue.enumerate(issues, astype=tuple):
-            return None
-
         return AspirationNegotiator(
             ufun=self.create_ufun(is_seller=is_seller, issues=issues),
-            assume_normalized=True,
         )
 
     def on_negotiation_failure(
@@ -379,7 +365,7 @@ class GFM2(SCML2020Agent):
             return -1000000.0
 
         if min(est_stock_cap) < 0:
-            return sum([s for s in est_stock_cap if s < 0])
+            return sum(s for s in est_stock_cap if s < 0)
 
         # 各要素に対する評価値 [0,1]
         # 生産ライン
@@ -408,7 +394,7 @@ class GFM2(SCML2020Agent):
     def simulate_set(
         self, buy_conts: List[Contract], sell_conts: List[Contract]
     ) -> Tuple[Optional[List[int]], Optional[List[int]], Optional[int]]:
-        """ returns (estimated_line_cap, profit, estimated_stock_cap) """
+        """returns (estimated_line_cap, profit, estimated_stock_cap)"""
 
         profit = 0
         est_line_cap = self.line_cap
@@ -614,11 +600,11 @@ class MySpecialUtilityFunction(UtilityFunction):
         self,
         is_seller: bool,
         name: Optional[str] = None,
-        reserved_value: UtilityValue = float("-inf"),
+        reserved_value: Value = float("-inf"),
         outcome_type: Optional[Type] = None,
         issue_names: Optional[List[str]] = None,
         issues: List["Issue"] = None,
-        ami: AgentMechanismInterface = None,
+        nmi: AgentMechanismInterface = None,
         awi: AWI = None,
     ) -> None:
         self.is_seller = is_seller
@@ -627,13 +613,12 @@ class MySpecialUtilityFunction(UtilityFunction):
         super().__init__(
             name=name,
             reserved_value=reserved_value,
-            outcome_type=outcome_type,
             issue_names=issue_names,
             issues=issues,
-            ami=ami,
+            nmi=nmi,
         )
 
-    def eval(self, offer: "Outcome") -> UtilityValue:
+    def eval(self, offer: "Outcome") -> Value:
         price, quantity, date = offer
 
         if self.is_seller:
